# Data and R code to reproduce exemplaric results of the reactivity continuum model analysis
# published in Koehler et al., Reactivity continuum of dissolved organic carbon 
# decomposition in lake water, Journal of Geophysical Research Biogeosciences 117, 
# doi:10.1029/2011JG001793, 2012

# The script does not contain all analyses or model selection steps, tests or (e.g.) diagnostic plots which were conducted 
# during data exploration or analysis, but central code as example of how the RC model
# can be used with R

# The script was compiled in October 2015 by B. Koehler

# For questions, comments or further requests please contact Birgit Koehler, birgit.koehler@ebc.uu.se

# If planning to use the data please contact Birgit Koehler and Lars Tranvik (lars.tranvik@ebc.uu.se) to inform us about the purpose

library(nlme)

rm(list=ls())
# Working directory, needs to be adapted
setwd("~/Documents")

# read data
LabilityControl<-read.table("RC_model_example_file.txt",header=T,na.strings="NA")
attach(LabilityControl)

# Estimate the model parameters (Table 4) using a non-linear mixed effects model 
# 'Category' is Clearwater vs. Brownwater lakes (fixed effect)
# 'Lake' is the 3 different lakes per Category (random effect)
# aa and vv are the model parameters (eq. 2)

model = nlme(TOC~(aa*(aa+Day)^-1)^vv,fixed=aa+vv~Category-1,random=aa+vv~1|Lake,data=LabilityControl,
na.action=na.exclude,start=c(aa=rep(20,2),vv=rep(0.1,2)),method="ML")
summary(model) # gives the parameter estimates directly due to the command '-1' in the fixed effect

# For statistical testing (in this case whether the parameter estimates differ between the
# clear- and brownwater lakes) make a similar model but without the '-1' command:
model2 = nlme(TOC~(aa*(aa+Day)^-1)^vv,fixed=aa+vv~Category,random=aa+vv~1|Lake,data=LabilityControl,
na.action=na.exclude,start=c(aa=rep(20,2),vv=rep(0.1,2)),method="ML")
anova(model2) # Test for differences in the parameter estimates

# Calculate the probability distributions (Fig. 3a)
probxxx=seq(0,0.03,0.0001) # Range on the x-axis
probyyy=matrix(ncol=2,nrow=length(probxxx))
for (i in 1:2)
{probyyy[,i]=pgamma(probxxx,fixef(model)[i+2],rate=fixef(model)[i])}  # rate is the parameter alpha from eq. 2

# Calculate the reactivity classes for each lake using the random effects for each Category
# Table 3
RC1=double();RC2=double();RC3=double()
i=1
# Clearwater lakes
for (i in 1:2)
# Lisa and Lj
{RC3[i] = pgamma(0.001,fixef(model)[4]+data.frame(ranef(model)[2])[i,1],
                        rate=fixef(model)[2]+data.frame(ranef(model)[2])[i,1],lower.tail=T) # <=0.001
RC1[i] = 1-pgamma(0.01,fixef(model)[4]+data.frame(ranef(model)[2])[i,1],
                      rate=fixef(model)[2]+data.frame(ranef(model)[2])[i,1],lower.tail=T)} # >=0.01}
# Valloxen
RC3[3] = pgamma(0.001,fixef(model)[4]+data.frame(ranef(model)[2])[6,1],
                       rate=fixef(model)[2]+data.frame(ranef(model)[2])[6,1],lower.tail=T) # <=0.001
RC1[3] = 1-pgamma(0.01,fixef(model)[4]+data.frame(ranef(model)[2])[6,1],
                     rate=fixef(model)[2]+data.frame(ranef(model)[2])[6,1],lower.tail=T) # >=0.01
# Brownwater lakes
for (i in 1:3)  # Lu, Si, ST_L
{RC3[i+3] = pgamma(0.001,fixef(model)[3]+data.frame(ranef(model)[2])[i+2,1],
                          rate=fixef(model)[1]+data.frame(ranef(model)[2])[i+2,1],lower.tail=T) # <=0.001
RC1[i+3] = 1-pgamma(0.01,fixef(model)[3]+data.frame(ranef(model)[2])[i+2,1],
                        rate=fixef(model)[1]+data.frame(ranef(model)[2])[i+2,1],lower.tail=T)} # >=0.01

RC2 = 1-RC3-RC1
